netapp_ontap.resources.consistency_group_snapshot API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.consistency_group_snapshot`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Overview

Consistency groups support snapshot create, inventory, and restore. Snapshots can be created on a specified schedule or on-demand. On-demand snapshots can have a type of application consistent or crash consistent. Crash consistent is the default. Scheduled snapshotss are always crash consistent. There is no functional difference in ONTAP between crash consistent or application consistent snapshots.
The functionality provided by these APIs is not integrated with the host application. Snapshots have limited value without host coordination, so the use of the SnapCenter Backup Management suite is recommended to ensure correct interaction between host applications and ONTAP.

### On-Demand Snapshots

A manual snapshot may be created on-demand for a parent consistency group and for any of the children consistency groups within it.
Scheduled and manual snapshot creation operations are subject to a pre-defined seven second internal timeout. If the snapshot creation operation does not complete within this time, it is aborted.
Individual volume snapshots within a consistency group snapshots can be accessed and used with native volume snapshot operations.
When an individual volume snapshot is deleted that is part of a consistency group snapshot, then that consistency group snapshot becomes invalid and which cannot be used for restoring the consistency group.

### Restoring to a Previous Snapshot

A snapshot restores to a parent consistency group from an existing parent consistency group's snapshot. A snapshot restores to any of the children's consistency groups within it from an existing children's consistency group. Granular snapshots are supported. This is performed by a PATCH operation on the specific consistency group for the restore. An example is shown in `PATCH /application/consistency-groups`.
Any existing snapshots that were created chronologically after the time of the snapshot used in a successful restore operation is deleted, in compliance with existing ONTAP "future-snapshot" handling principles.
On failures during consistency group restores, any volumes that have been restored will remain so and will not be rolled back. The user must retry the failed restore operation until it is successful. The user can retry with consistency group restore or individual volume-granular restore.

## Consistency group Snapshot APIs

The following APIs are used to perform operations related to consistency group snapshots:

- GET /api/application/consistency-groups/{consistency_group.uuid}/snapshots
- POST /api/application/consistency-groups/{consistency_group.uuid}/snapshots
- POST /api/application/consistency-groups/{consistency_group.uuid}/snapshots?action=start
- GET /api/application/consistency-groups/{consistency_group.uuid}/snapshots/{uuid}
- PATCH /api/application/consistency-groups/{consistency_group.uuid}/snapshots/{uuid}?action=commit
- DELETE /api/application/consistency-groups/{consistency_group.uuid}/snapshots/{uuid}

## Examples

### Required properties

- `consistency_group.uuid` - Existing consistency group UUID in which to create the snapshot.

### Retrieving the list of existing snapshots for a consistency group

Retrieves the list of consistency group granular snapshots for a specific consistency group.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import ConsistencyGroupSnapshot

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(
            list(
                ConsistencyGroupSnapshot.get_collection(
                    "92c6c770-17a1-11eb-b141-005056acd498"
                )
            )
        )

Try it out

    [
        ConsistencyGroupSnapshot(
            {
                "name": "sa3s1",
                "_links": {
                    "self": {
                        "href": "/api/application/consistency-groups/a8d0626a-17a0-11eb-b141-005056acd498/snapshots/92c6c770-17a1-11eb-b141-005056acd498"
                    }
                },
                "uuid": "92c6c770-17a1-11eb-b141-005056acd498",
            }
        ),
        ConsistencyGroupSnapshot(
            {
                "name": "sa3s2",
                "_links": {
                    "self": {
                        "href": "/api/application/consistency-groups/a8d0626a-17a0-11eb-b141-005056acd498/snapshots/c5a250ba-17a1-11eb-b141-005056acd498"
                    }
                },
                "uuid": "c5a250ba-17a1-11eb-b141-005056acd498",
            }
        ),
    ]

### Retrieves details of a specific snapshot for a consistency group

Retrieves details for a specific snapshot in a consistency group.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import ConsistencyGroupSnapshot

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = ConsistencyGroupSnapshot(
            "92c6c770-17a1-11eb-b141-005056acd498",
            uuid="a175c021-4199-11ec-8674-005056accf3f",
        )
        resource.get()
        print(resource)

Try it out

    ConsistencyGroupSnapshot(
        {
            "name": "sa3s2",
            "consistency_type": "crash",
            "_links": {
                "self": {
                    "href": "/api/application/consistency-groups/ddabc6a5-4196-11ec-8674-005056accf3f/snapshots/a175c021-4199-11ec-8674-005056accf3f"
                }
            },
            "comment": "manually created snapshot",
            "create_time": "2021-11-09T15:14:23-05:00",
            "uuid": "a175c021-4199-11ec-8674-005056accf3f",
            "consistency_group": {
                "name": "CG_1",
                "_links": {
                    "self": {
                        "href": "/api/application/consistency-groups/ddabc6a5-4196-11ec-8674-005056accf3f"
                    }
                },
                "uuid": "ddabc6a5-4196-11ec-8674-005056accf3f",
            },
            "svm": {
                "name": "vs1",
                "_links": {
                    "self": {"href": "/api/svm/svms/7379fecb-4195-11ec-8674-005056accf3f"}
                },
                "uuid": "7379fecb-4195-11ec-8674-005056accf3f",
            },
        }
    )

### Retrieving bulk snapshots

Retrieves the list of consistency group granular snapshots for all consistency groups on the cluster.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import ConsistencyGroupSnapshot

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(ConsistencyGroupSnapshot.get_collection("*")))

Try it out

    [
        ConsistencyGroupSnapshot(
            {
                "name": "cg3ss",
                "_links": {
                    "self": {
                        "href": "/api/application/consistency-groups/1218f900-c124-11ee-bbfe-005056acb65e/snapshots/7da4d364-c12e-11ee-bbfe-005056acb65e"
                    }
                },
                "uuid": "7da4d364-c12e-11ee-bbfe-005056acb65e",
                "consistency_group": {
                    "name": "cg3",
                    "_links": {
                        "self": {
                            "href": "/api/application/consistency-groups/1218f900-c124-11ee-bbfe-005056acb65e"
                        }
                    },
                    "uuid": "1218f900-c124-11ee-bbfe-005056acb65e",
                },
            }
        ),
        ConsistencyGroupSnapshot(
            {
                "name": "cg2ss",
                "_links": {
                    "self": {
                        "href": "/api/application/consistency-groups/15a8f66e-c124-11ee-bbfe-005056acb65e/snapshots/83595384-c12e-11ee-bbfe-005056acb65e"
                    }
                },
                "uuid": "83595384-c12e-11ee-bbfe-005056acb65e",
                "consistency_group": {
                    "name": "cg2",
                    "_links": {
                        "self": {
                            "href": "/api/application/consistency-groups/15a8f66e-c124-11ee-bbfe-005056acb65e"
                        }
                    },
                    "uuid": "15a8f66e-c124-11ee-bbfe-005056acb65e",
                },
            }
        ),
        ConsistencyGroupSnapshot(
            {
                "name": "cg1ss",
                "_links": {
                    "self": {
                        "href": "/api/application/consistency-groups/1c101d17-c124-11ee-bbfe-005056acb65e/snapshots/87d0e49c-c12e-11ee-bbfe-005056acb65e"
                    }
                },
                "uuid": "87d0e49c-c12e-11ee-bbfe-005056acb65e",
                "consistency_group": {
                    "name": "cg1",
                    "_links": {
                        "self": {
                            "href": "/api/application/consistency-groups/1c101d17-c124-11ee-bbfe-005056acb65e"
                        }
                    },
                    "uuid": "1c101d17-c124-11ee-bbfe-005056acb65e",
                },
            }
        ),
    ]

### Creating a crash-consistent snapshot of a consistency group

Creates an on-demand crash-consistent snapshot of an existing consistency group.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import ConsistencyGroupSnapshot

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = ConsistencyGroupSnapshot("a8d0626a-17a0-11eb-b141-005056acd498")
        resource.name = "name_of_this_snapshot"
        resource.consistency_type = "crash"
        resource.comment = "this is a manually created on-demand snapshot"
        resource.snapmirror_label = "my_special_sm_label"
        resource.post(hydrate=True)
        print(resource)

### Creating a app-consistent snapshot of a consistency group

Creates an on-demand crash-consistent snapshot of an existing consistency group.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import ConsistencyGroupSnapshot

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = ConsistencyGroupSnapshot("a8d0626a-17a0-11eb-b141-005056acd498")
        resource.name = "name_of_this_snapshot"
        resource.consistency_type = "application"
        resource.comment = "this is a manually created on-demand snapshot"
        resource.snapmirror_label = "my_special_sm_label"
        resource.post(hydrate=True)
        print(resource)

### Starting a two-phase crash-consistent snapshot creation for a consistency group

Starts a two-phase on-demand crash-consistent snapshot creation for an existing consistency group.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import ConsistencyGroupSnapshot

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = ConsistencyGroupSnapshot("a8d0626a-17a0-11eb-b141-005056acd498")
        resource.name = "name_of_this_snapshot"
        resource.consistency_type = "application"
        resource.comment = "this is a manually created on-demand snapshot"
        resource.snapmirror_label = "my_special_sm_label"
        resource.post(hydrate=True, action="start", action_timeout=7)
        print(resource)

### Committing a previously started two-phase crash-consistent snapshot creation for a consistency group

Commits a previously started two-phase on-demand crash-consistent snapshot creation for an existing consistency group.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import ConsistencyGroupSnapshot

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = ConsistencyGroupSnapshot(
            "a8d0626a-17a0-11eb-b141-005056acd498",
            uuid="7aac0607-0c4d-11ee-ad32-005056a73101",
        )
        resource.patch(hydrate=True, action="commit")

### Deleting a snapshot from a consistency group

Deletes an existing snapshot from a consistency group.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import ConsistencyGroupSnapshot

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = ConsistencyGroupSnapshot(
            "a8d0626a-17a0-11eb-b141-005056acd498",
            uuid="92c6c770-17a1-11eb-b141-005056acd498",
        )
        resource.delete()

## Classes

`class ConsistencyGroupSnapshot (*args, **kwargs)`

  Allows interaction with ConsistencyGroupSnapshot objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection (*args, connection: HostConnection = None, **kwargs) -> int`

    Returns a count of all ConsistencyGroupSnapshot resources that match the provided query

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection (*args, records: Iterable[ForwardRef('ConsistencyGroupSnapshot')] = None, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes a snapshot of a consistency group.

    ## Examples

    ### Learn more

    - `DOC /application/consistency-groups/{consistency_group.uuid}/snapshots`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `records`
      Can be provided in place of a query. If so, this list of objects will be deleted from the host.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be deleted.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def fast_get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[RawResource]`

    Returns a list of RawResources that represent ConsistencyGroupSnapshot resources that match the provided query

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def find (*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves snapshots for a consistency group.

    ## Expensive properties

    There is an added computational cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See `DOC Requesting specific fields` to learn more. * `is_partial` * `missing_volumes.uuid` * `missing_volumes.name`

    ### Learn more

    - `DOC /application/consistency-groups/{consistency_group.uuid}/snapshots`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[Resource]`

    Retrieves snapshots for a consistency group.

    ## Expensive properties

    There is an added computational cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See `DOC Requesting specific fields` to learn more. * `is_partial` * `missing_volumes.uuid` * `missing_volumes.name`

    ### Learn more

    - `DOC /application/consistency-groups/{consistency_group.uuid}/snapshots`

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection (body: dict, *args, records: Iterable[ForwardRef('ConsistencyGroupSnapshot')] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Completes a snapshot operation of a consistency group. This can also be used to modify the SnapLock expiry time of a locked snapshot in SnapLock for SnapVault destination.

    ## Example

    ### Completing a snapshot operation

    The following example shows how to complete the snapshot operation by committing an existing snapshot to disk: `curl -X PATCH <https://<mgmt-ip>>/api/application/consistency-groups/a8d0626a-17a0-11eb-b141-005056acd498/snapshots/92c6c770-17a1-11eb-b141-005056acd498?action=commit`

    #### Response:

    `{ }`

    ### Modifying the SnapLock expiry time of a snapshot in SnapLock for SnapVault

    The following example shows how to modify the SnapLock expiry time of a locked snapshot in SnapLock for SnapVault destination: `curl -X PATCH 'https://<mgmt-ip>/api/application/consistency-groups/a8d0626a-17a0-11eb-b141-005056acd498/snapshots/92c6c770-17a1-11eb-b141-005056acd498' -d '{"snaplock.expiry_time" : "2/28/2024 10:11:10 +05:30"}' -H "accept: application/hal+json"`

    #### Response:

    `{ "job": { "uuid": "8c9cabf3-0a88-11ec-a449-005056bbcf9f", "_links": { "self": { "href": "/api/cluster/jobs/8c9cabf3-0a88-11ec-a449-005056bbcf9f" } } } }`

    ### Learn more

    - `DOC /application/consistency-groups/{consistency_group.uuid}/snapshots`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection. The body argument will be ignored if records is provided.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `records`
      Can be provided in place of a query. If so, this list of objects will be patched on the host.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post_collection (records: Iterable[ForwardRef('ConsistencyGroupSnapshot')], *args, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> Union[List[ConsistencyGroupSnapshot], NetAppResponse]`

    Creates a snapshot of an existing consistency group.

    ### Required properties

    - `consistency_group.uuid` - Existing consistency group UUID in which to create the snapshot.

    ### Learn more

    - `DOC /application/consistency-groups/{consistency_group.uuid}/snapshots`

    Send this collection of objects to the host as a creation request.

    ## Args

    `records`
      A list of `Resource` objects to send to the server to be created.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to create a bar for a particular foo, the foo.name value should be passed.
    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of each object. When hydrate is set to True, poll must also be set to True.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A list of `Resource` objects matching the provided type which have been created by the host and returned. This is not the same list that was provided, so to continue using the object, you should save this list. If poll is set to False, then a `NetAppResponse` object is returned instead.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete (self, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Deletes a snapshot of a consistency group.

    ## Examples

    ### Learn more

    - `DOC /application/consistency-groups/{consistency_group.uuid}/snapshots`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get (self, **kwargs) -> NetAppResponse`

    Retrieves details of a specific snapshot for a consistency group.

    ### Expensive properties

    There is an added computational cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See `DOC Requesting specific fields` to learn more. * `is_partial` * `missing_volumes.uuid` * `missing_volumes.name`

    ### Learn more

    - `DOC /application/consistency-groups/{consistency_group.uuid}/snapshots`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400 or if not all of the keys required are present and config.STRICT_GET has been set to True.

  `def patch (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Completes a snapshot operation of a consistency group. This can also be used to modify the SnapLock expiry time of a locked snapshot in SnapLock for SnapVault destination.

    ## Example

    ### Completing a snapshot operation

    The following example shows how to complete the snapshot operation by committing an existing snapshot to disk: `curl -X PATCH <https://<mgmt-ip>>/api/application/consistency-groups/a8d0626a-17a0-11eb-b141-005056acd498/snapshots/92c6c770-17a1-11eb-b141-005056acd498?action=commit`

    #### Response:

    `{ }`

    ### Modifying the SnapLock expiry time of a snapshot in SnapLock for SnapVault

    The following example shows how to modify the SnapLock expiry time of a locked snapshot in SnapLock for SnapVault destination: `curl -X PATCH 'https://<mgmt-ip>/api/application/consistency-groups/a8d0626a-17a0-11eb-b141-005056acd498/snapshots/92c6c770-17a1-11eb-b141-005056acd498' -d '{"snaplock.expiry_time" : "2/28/2024 10:11:10 +05:30"}' -H "accept: application/hal+json"`

    #### Response:

    `{ "job": { "uuid": "8c9cabf3-0a88-11ec-a449-005056bbcf9f", "_links": { "self": { "href": "/api/cluster/jobs/8c9cabf3-0a88-11ec-a449-005056bbcf9f" } } } }`

    ### Learn more

    - `DOC /application/consistency-groups/{consistency_group.uuid}/snapshots`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Creates a snapshot of an existing consistency group.

    ### Required properties

    - `consistency_group.uuid` - Existing consistency group UUID in which to create the snapshot.

    ### Learn more

    - `DOC /application/consistency-groups/{consistency_group.uuid}/snapshots`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class ConsistencyGroupSnapshotSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ConsistencyGroupSnapshot object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `comment: str GET POST`

    Comment for the snapshot.

    Example: My snapshot comment

  `consistency_group: ConsistencyGroup GET`

    The consistency_group field of the consistency_group_snapshot.

  `consistency_type: str GET POST PATCH`

    Consistency type. This is for categorization purposes only. A snapshot should not be set to 'application consistent' unless the host application is quiesced for the snapshot. Valid in POST.

    Valid choices:

    - crash
    - application
  `create_time: ImpreciseDateTime GET`

    Time the snapshot copy was created

    Example: 2020-10-25T11:20:00.000+0000

  `is_partial: bool GET`

    Indicates whether the snapshot taken is partial or not.

    Example: false

  `links: SelfLink GET`

    The links field of the consistency_group_snapshot.

  `luns: List[Lun] GET`

    The list of LUNs in this snapshot.

  `missing_luns: List[Lun] GET`

    List of LUNs that are not in the snapshot.

  `missing_namespaces: List[NvmeNamespace] GET`

    List of NVMe namespaces that are not in the snapshot.

  `missing_volumes: List[Volume] GET`

    List of volumes which are not in the snapshot.

  `name: str GET POST PATCH`

    Name of the snapshot.

  `namespaces: List[NvmeNamespace] GET`

    The list of NVMe namespaces in this snapshot.

  `reclaimable_space: Size GET`

    Space reclaimed when the snapshot is deleted, in bytes.

  `restore_size: Size GET`

    Size of the consistency group if this snapshot is restored.

    Example: 4096

  `snaplock: ConsistencyGroupSnapshotSnaplock GET POST PATCH`

    SnapLock Snapshot attributes.

  `snapmirror_label: str GET POST`

    Snapmirror Label for the snapshot.

    Example: sm_label

  `snapshot_volumes: List[ConsistencyGroupVolumeSnapshot] GET`

    List of volume and snapshot identifiers for each volume in the snapshot.

  `svm: Svm GET POST PATCH`

    The SVM in which the consistency group is located.

  `uuid: str GET`

    The unique identifier of the snapshot. The UUID is generated by ONTAP when the snapshot is created.

    Example: 1cd8a442-86d1-11e0-ae1c-123478563412

  `write_fence: bool GET POST`

    Specifies whether a write fence will be taken when creating the snapshot. The default is false if there is only one volume in the consistency group, otherwise the default is true.